package com.fluig;

import javax.annotation.security.RunAs;
import javax.ejb.EJB;
import javax.ejb.Singleton;

import com.totvs.technology.foundation.alert.service.AlertAppSenderService;
import com.totvs.technology.foundation.common.SystemConstants;
import com.totvs.technology.foundation.common.exception.FDNException;

/**
 * Esta classe é responsável por registrar o aplicativo na Central de Notificações do Fluig.
 * 
 * @author caio.psousa@fluig.com
 *
 */
@RunAs(SystemConstants.TENANT_ADMIN_ROLE)
@Singleton(mappedName = "TxtServiceRegister", name = "TxtServiceRegister")
public class ServiceRegister {

	/**
	 * Este é um serviço da API de notificações do Fluig.
	 * É responsável por cadastrar na Central de Notificações um novo applicativo de envio de notificações.
	 */
	@EJB(lookup = AlertAppSenderService.JNDI_REMOTE_NAME)
	private AlertAppSenderService appSenderService;

	/**
	 * Registra o applicativo na Central de Notificações do Fluig.
	 * 
	 * @param tenantId - id do tenant para o qual o aplicativo será registrado
	 */
	public void registerApplication(Long tenantId) throws FDNException {
		
		/*
		 * Parâmetros necessários:
		 * 1. String que identifica o aplicativo no sistema (é o identificador único do aplicativo)
		 * 2. Descrição do aplicativo (pode ser cadastrada uma chave para tradução no I18n. Para isto,
		 * a chave deve estar cadastrada previamente no bundle foundation_alert
		 * 3. JNDI do serviço que a Central de Notificações irá acionar para enviar os alertas por este
		 * aplicativo.
		 * 4. Id do tenant para o qual o aplicativo será registrado.
		 */
		appSenderService
				.registerApplication(
						"TxtSender",
						"Txt file",
						"java:global/alertsendersample/alert-sender-sample-impl/txt/TxtSenderService!com.totvs.technology.foundation.alert.sender.AlertSenderApp",
						tenantId);
		
	}

}
