package com.fluig;

import javax.annotation.security.RunAs;
import javax.ejb.ActivationConfigProperty;
import javax.ejb.EJB;
import javax.ejb.MessageDriven;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.ObjectMessage;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.totvs.technology.foundation.common.SystemConstants;
import com.totvs.technology.foundation.common.exception.FDNException;
import com.totvs.technology.foundation.sdk.service.FDNEvents;
import com.totvs.technology.foundation.sdk.service.FDNTransferObject;

/**
 * Esta classe é responsável por cadastrar o aplicativo de envio de notificações
 * na criação de um novo tenant.
 * 
 * OBS: Este processo é opcional. O aplicativo pode ser registrado na Central de Notificações
 * a qualquer momento.
 * 
 * @author caio.psousa@fluig.com
 */
@MessageDriven(activationConfig = {
		@ActivationConfigProperty(propertyName = "acknowledgeMode", propertyValue = "Auto-acknowledge"),
		@ActivationConfigProperty(propertyName = "destinationType", propertyValue = "javax.jms.Topic"),
		@ActivationConfigProperty(propertyName = "destination", propertyValue = "TOTVSTechIntegrationListenerTopic") })
@RunAs(SystemConstants.TENANT_ADMIN_ROLE)
public class TopicListener implements MessageListener {

	private transient Logger LOG = LoggerFactory.getLogger(TopicListener.class);
	
	@EJB
	private ServiceRegister serviceRegister;

	/**
	 * Ouve o evento do Fluig de criação de novo tenant e cadastra o aplicativo
	 * na Central de Notificações daquele tenant.
	 */
	@Override
	public void onMessage(Message message) {
		
		final ObjectMessage msg = (ObjectMessage) message;
		
		try {

			final String event = msg.getStringProperty("event");
			final FDNTransferObject param = (FDNTransferObject) msg.getObject();
			
			if (event.equals(FDNEvents.CREATE_TENANT.getEvent())) {
				
				final Long tenantId = (Long) param.getValue("id");
				serviceRegister.registerApplication(tenantId);
				
			}
			
		} catch (FDNException | JMSException ex) {
			LOG.error("Could not register txt sender application for tenant: " + ex.getMessage());
		}

	}

}
